.. highlight:: shell

============
Installation
============


From Pypi
------------

Stable release
--------------


To install NDEx2 Python Client, run this command in your terminal:

.. code-block:: console

    pip install ndex2

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: https://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for NDEx2 Python Client can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    git clone git://github.com/ndexbio/ndex2-client

Or download the `tarball`_:

.. code-block:: console

    curl  -OL https://github.com/ndexbio/ndex2-client/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    python setup.py install


.. _Github repo: https://github.com/ndexbio/ndex2-client
.. _tarball: https://github.com/ndexbio/ndex2-client/tarball/master
